<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Monitor de Sistema</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>O Monitor de Sistema é uma ferramenta para monitorar a carga do sistema em tempo real, exibir e controlar processos e serviços em execução no sistema.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Ocultar detalhes</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Ler</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 segundos</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 dias %2 horas %3 minutos</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Utilização</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Frequência atual</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequência</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Sockets</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Processadores lógicos</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualização</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Cache L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Cache L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Cache L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Cache L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Carga média</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Descritores de arquivo</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Processos</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Threads</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nome do host</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Tipo de SO</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Tempo de atividade</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 segundos</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>ativo</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>recarregando</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inativo</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>failed</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>ativando</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>desativando</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>not-found</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>bad-setting</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erro</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>mesclado</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>mascarado</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>carregado</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>ativado</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>desativado</translation>
    </message>
    <message>
        <source>static</source>
        <translation>estático</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>transitório</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indireto</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>enabled-runtime</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>mascarado</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>gerado</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>morto</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>iniciar</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>executando</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>exited</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>recarregar</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>falhou</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-reiniciar</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Utilizado</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponível</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Compartilhada</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Em cache</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Buffers</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>SWAP em cache</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Sujo</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mapeado</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>SWAP total</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>SWAP livre</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Placa</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Velocidade de leitura</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Velocidade de gravação</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Capacidade</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Setores lidos</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Leituras / s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Setores lidos / s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Leituras mescladas / s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Setores gravados</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Gravações concluídas</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Gravações mescladas</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Gravações / s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Setores gravados / s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Gravações mescladas / s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Encerrar este processo poderá causar a perda de dados.
Continuar?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Encerrar processo</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forçar o encerramento deste processo, poderá causar a perda de dados.
Continuar?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forçar o encerramento deste aplicativo, poderá causar a perda de dados.
Continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Forçar encerrar</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Encerrar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Endereço de IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Máscara de Sub-rede:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Transmissão:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Âmbito:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Tipo de conexão</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Qualidade do link</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Força do sinal</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Nível de ruído</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Largura de banda</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Pacotes Rx</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Bytes Rx</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Erros Rx</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>Rx descartado</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Rx overruns</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Rx frame</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Pacotes Tx</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Bytes Tx</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Erros Tx</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Tx overruns</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Transportador Tx</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>Tx descartado</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Linha de comando</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Hora de início</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Clique no aplicativo que deseja encerrar</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Receber</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Leitura de disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escrita de disco</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>RAM</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>SWAP</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Inativa</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Total Baixado</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Total Enviado</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discos</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Muito alta</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Muito baixa</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizada</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Erro: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Falha ao alterar a prioridade do processo</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Aplicativos</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Processos do usuário</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos os processos</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Falha ao pausar o processo</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Falha ao retomar o processo</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Falha ao interromper o processo</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Falha no envio do sinal para o processo</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Falha ao finalizar o processo</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplicativos e %2 processos estão em execução)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Sem resposta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Visualizar o local do comando</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Encerrar processo</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Retomar processo</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Interromper processo</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Alterar prioridade</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender processo</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Prioridade Personalizada</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Alterar</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escrita de disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Leitura de disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Prioridade na CPU</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioridade</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Memória compartilhada</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Memória virtual</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Sem suporte</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Proteção do sistema</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Mostrar avisos quando o uso exceder os limites</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificações</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Aviso sobre limite da CPU (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Aviso sobre limite da memória (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Intervalo entre avisos (min)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Falha ao definir o tipo de inicialização do serviço</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Erro: falha ao definir o tipo de inicialização do serviço devido ao subprocesso com falha.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Nome de instância do serviço</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parado</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Tipo de inicialização</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Carga</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Status de execução</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Tipo de Inicialização</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Modificável)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Intervalo: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Forçar encerramento de aplicativo</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandida</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Compacta</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualização</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Processos</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Serviços</translation>
    </message>
</context>
</TS>
